package me.unurled.sacredrealms.cutscenes;

import java.util.ArrayList;
import org.bukkit.Location;

public class Marker {

    private static int idCounter = 0;
    private static ArrayList<Marker> markers = new ArrayList<>();
    private final int ID;
    private ArrayList<Frame> frames;
    private Long timeBetweenFrames;
    private Long overAllTime;
    private Location start;


    public Marker(Integer id) {
        frames = new ArrayList<>();
        timeBetweenFrames = 0L;
        overAllTime = 0L;
        if (id == null) {
            ID = idCounter;
            idCounter++;
        } else {
            ID = id;
        }
    }

    public Marker(ArrayList<Frame> frames, long timeBetweenFrames, Location start) {
        this.frames = frames;
        this.timeBetweenFrames = timeBetweenFrames;
        this.overAllTime = timeBetweenFrames * frames.size();
        this.start = start;
        ID = idCounter;
        idCounter++;
    }

    public ArrayList<Frame> getFrames() {
        return frames;
    }

    public Long getTimeBetweenFrames() {
        return timeBetweenFrames;
    }

    public Long getOverAllTime() {
        return overAllTime;
    }

    public void setFrames(ArrayList<Frame> frames) {
        this.frames = frames;
    }

    public void setTimeBetweenFrames(Long timeBetweenFrames) {
        this.timeBetweenFrames = timeBetweenFrames;
    }

    public void setOverAllTime(Long overAllTime) {
        this.overAllTime = overAllTime;
    }

    public Location getStart() {
        return start;
    }

    public void calculateFrames(Marker endMarker) {
        frames = MarkerInterpolator.interpolateFrames(this, endMarker, timeBetweenFrames);
    }

    public void setStart(Location start) {
        this.start = start;
    }

    public int getID() {
        return ID;
    }

    public void addFrame(Frame frame) {
        frames.add(frame);
    }

    public void removeFrame(Frame frame) {
        frames.remove(frame);
    }

    public void removeFrame(int index) {
        frames.remove(index);
    }

    public static ArrayList<Marker> getMarkers() {
        return markers;
    }

    public static Marker getMarker(int ID) {
        for (Marker marker : markers) {
            if (marker.getID() == ID) {
                return marker;
            }
        }
        return null;
    }

    @Override
    public String toString() {
        return "Marker{" + "ID=" + ID + ", frames=" + frames + ", timeBetweenFrames=" + timeBetweenFrames + ", overAllTime=" + overAllTime + ", start=" + start + '}';
    }

    public static void setMarkers(ArrayList<Marker> markers) {
        Marker.markers = markers;
    }
}
